@@ -382,9 +382,9 @@ EAction.prototype.showUiOptions = function(resume, restoreFromSettings) {
 
         // show:
         this.settingsGroup = wOptions.objectName;
-        this.optionWidgetActions = this.optionWidgetActions
-                .concat(WidgetFactory.moveChildren(wOptions, optionsToolBar,
-                        this.settingsGroup));
+        var movedWidgets = WidgetFactory.moveChildren(wOptions, optionsToolBar, this.settingsGroup);
+
+        this.optionWidgetActions = this.optionWidgetActions.concat(movedWidgets);
 
         // required for undocked options tool bar:
         if (optionsToolBar.floating) {
@@ -399,11 +399,16 @@ EAction.prototype.showUiOptions = function(resume, restoreFromSettings) {
 
         // give action a chance to initialize toolbar widgets that cannot
         // be initialized in Qt Designer:
-        this.initUiOptions(resume, optionsToolBar);
+        if (i===this.uiFile.length-1) {
+            this.initUiOptions(resume, optionsToolBar);
+        }
 
         // restore previously stored state:
         if (restoreFromSettings===true) {
+            // make sure auto focus widgets are not activated while restoring:
+            optionsToolBar.setProperty("Restoring", true);
             WidgetFactory.restoreState(optionsToolBar, this.settingsGroup, this);
+            optionsToolBar.setProperty("Restoring", false);
         }
     }
 
@@ -418,36 +423,11 @@ EAction.prototype.showUiOptions = function(resume, restoreFromSettings) {
  * bar.
  */
 EAction.prototype.initUiOptions = function(resume, optionsToolBar) {
-    var prefixChar = RSettings.getStringValue("ToolBar/PrefixChar", ",");
-
     if (isNull(optionsToolBar)) {
         return;
     }
 
-    var children = optionsToolBar.children();
-    for (var i=0; i<children.length; i++) {
-        var child = children[i];
-        if (isNull(child)) {
-            continue;
-        }
-
-        var shortCut = child.shortcut;
-        if (!isNull(shortCut) && !shortCut.isEmpty()) {
-            var str = shortCut.toString();
-            var firstChar = str[0];
-
-            // if first key is Ctrl then the string starts with Ctrl+
-            // so check for a + sign, which indicates a modifier key has been used
-            // '+' and '-' should not be used as prefix, as they zoom in and out
-            if (str.indexOf('+') === -1) {                       // no plus sign
-                if (firstChar >= '!' && firstChar <= '~') {      // isgraph()
-                    str = str.replace(firstChar, prefixChar);
-                    child.shortcut = new QKeySequence(str);
-                    child.toolTip = RGuiAction.formatToolTip(child.toolTip, str);
-                }
-            }
-        }
-    }
+    OptionsToolBar.initShortcuts(optionsToolBar);
 };
 
 /**
@@ -480,8 +460,8 @@ EAction.prototype.hideUiOptions = function(saveToSettings) {
 
     // automatically reset icon of current action from toolbar:
     if (!isNull(this.getGuiAction()) &&
-            this.getGuiAction().getGroup() !== "snaps" &&
-            this.getGuiAction().getGroup() !== "snaprestrictions") {
+        this.getGuiAction().getGroup() !== "snaps" &&
+        this.getGuiAction().getGroup() !== "snaprestrictions") {
 
         if (!this.getGuiAction().icon.isNull()) {
             var iconLabel = optionsToolBar.findChild("Icon");
@@ -496,7 +476,8 @@ EAction.prototype.hideUiOptions = function(saveToSettings) {
     var i;
     while (this.optionWidgetActions.length>0) {
         var a = this.optionWidgetActions.pop();
-        if (!isNull(optionsToolBar)) {
+        // QButtonGroup objects are not actions that can be removed but need to be destroyed:
+        if (!isNull(optionsToolBar) && isQAction(a)) {
             optionsToolBar.removeAction(a);
         }
         destr(a);
@@ -724,26 +705,6 @@ EAction.prototype.escapeEvent = function() {
  * Called when the user presses a key. By default, the event is ignored.
  */
 EAction.prototype.keyPressEvent = function(event) {
-    if (isNull(event)) {
-        return;
-    }
-
-    // prevent focus shift when entering keycode (e.g. "D2"):
-    var appWin = EAction.getMainWindow();
-    if (appWin.getKeyLog().length===0) {
-        if ((event.key() >= Qt.Key_0.valueOf() && event.key() <= Qt.Key_9.valueOf()) || event.key() === Qt.Key_Period.valueOf()) {
-            // number or dot entered:
-            // give focus to first input widget in options tool bar and set text to number entered:
-            var w = OptionsToolBar.getFirstInputWidget();
-            if (!isNull(w)) {
-                w.setFocus(Qt.OtherFocusReason);
-                w.text = String.fromCharCode(event.key());
-                event.accept();
-                return;
-            }
-        }
-    }
-
     event.ignore();
 };
 
