@@ -277,6 +277,15 @@ function isQWidget(obj) {
     return (isQObject(obj) && typeof(obj.show)==="function");
 }
 
+/**
+ * Checks if the given object is a valid QAction.
+ *
+ * \return true if the given object is a QAction.
+ */
+function isQAction(obj) {
+    return (isQObject(obj) && typeof(obj.actionGroup)==="function");
+}
+
 /**
  * \return true if the given object is a separator (a frame of type vertical line).
  */
@@ -1945,7 +1954,7 @@ Array.prototype.clone = function() {
  */
 Array.prototype.sortNumerical = function() {
     Array.prototype.sort.call(this, function(a,b) { return a - b });
-}
+};
 
 Array.alphaNumericalSorter = function(a, b) {
     return RS.compareAlphanumerical(a, b);
@@ -2930,42 +2939,6 @@ function addActionsToWidgets() {
             }
             var w = appWin.findChild(wn);
             if (!isNull(w)) {
-
-                // workaround for QTBUG-38256 (action not triggered for letter based shortcuts in SUB menus):
-                // workaround for QTBUG-57990 (action not triggered for letter based shortcuts in ALL menus):
-                /*
-                if ((RSettings.getQtVersion()<0x050500 && RSettings.getQtVersion()>=0x050000) ||
-                    (RSettings.getQtVersion()===0x050800 && RS.getSystemId()==="linux")) {
-
-                    if (k===0) {
-                        var shortcuts = a.shortcuts();
-
-                        var scObjs = appWin.property("DelegatedShortcutsObjs");
-                        if (isNull(scObjs)) {
-                            scObjs=[];
-                        }
-                        for (var si=0; si<shortcuts.length; si++) {
-                            var scObj = new QShortcut(shortcuts[si], a.parentWidget(), 0, 0, Qt.WindowShortcut)
-                            scObj.activated.connect(a, a.trigger);
-                            scObjs.push(scObj);
-                        }
-                        appWin.setProperty("DelegatedShortcutsObjs", scObjs);
-
-                        var sc = a.shortcut.toString();
-                        if (sc.length>0) {
-                            if (RS.getSystemId()==="linux") {
-                                a.setShortcutText("[" + sc + "]");
-                            }
-                            else {
-                                a.setShortcutText(" " + sc);
-                            }
-                        }
-                        a.setProperty("DelegatedShortcuts", shortcuts);
-                        a.setDefaultShortcuts([]);
-                    }
-                }
-                */
-
                 if (visibility) {
                     RGuiAction.addToWidget(a, w);
                     addedToWidget = true;
